@@ -22,7 +22,7 @@ class CVodeSolver;
  *
  * The model does not contain any data, but represents the state
  * of the model at a specific time t. The states must not always be
- * in sync, but may be updated asynchroneously.
+ * in sync, but may be updated asynchronously.
  */
 class Model_ODE : public Model {
   public:
@@ -49,6 +49,8 @@ class Model_ODE : public Model {
      * repeating elements
      * @param ndwdp number of nonzero elements in the p derivative of the
      * repeating elements
+     * @param ndwdw number of nonzero elements in the w derivative of the
+     * repeating elements
      * @param ndxdotdw number of nonzero elements dxdotdw
      * @param ndJydy number of nonzero elements dJydy
      * @param nnz number of nonzero elements in Jacobian
@@ -62,23 +64,26 @@ class Model_ODE : public Model {
      * @param z2event mapping of event outputs to events
      * @param pythonGenerated flag indicating matlab or python wrapping
      * @param ndxdotdp_explicit number of nonzero elements dxdotdp_explicit
-     * @param ndxdotdp_implicit number of nonzero elements dxdotdp_implicit
+     * @param ndxdotdx_explicit number of nonzero elements dxdotdx_explicit
+     * @param w_recursion_depth Recursion depth of fw
      */
     Model_ODE(const int nx_rdata, const int nxtrue_rdata, const int nx_solver,
               const int nxtrue_solver, const int nx_solver_reinit, const int ny, const int nytrue,
               const int nz, const int nztrue, const int ne, const int nJ,
-              const int nw, const int ndwdx, const int ndwdp,
-              const int ndxdotdw, std::vector<int> ndJydy,
-              const int nnz, const int ubw, const int lbw,
-              const SecondOrderMode o2mode, std::vector<realtype> const &p,
-              std::vector<realtype> const &k, std::vector<int> const &plist,
+              const int nw, const int ndwdx, const int ndwdp, const int ndwdw,
+              const int ndxdotdw, std::vector<int> ndJydy, const int nnz,
+              const int ubw, const int lbw, const SecondOrderMode o2mode,
+              std::vector<realtype> const &p, std::vector<realtype> const &k,
+              std::vector<int> const &plist,
               std::vector<realtype> const &idlist,
               std::vector<int> const &z2event, const bool pythonGenerated=false,
-              const int ndxdotdp_explicit=0, const int ndxdotdp_implicit=0)
-        : Model(nx_rdata, nxtrue_rdata, nx_solver, nxtrue_solver, nx_solver_reinit, ny, nytrue,
-                nz, nztrue, ne, nJ, nw, ndwdx, ndwdp, ndxdotdw, std::move(ndJydy),
-                nnz, ubw, lbw, o2mode, p, k, plist, idlist, z2event,
-                pythonGenerated, ndxdotdp_explicit, ndxdotdp_implicit) {}
+              const int ndxdotdp_explicit=0, const int ndxdotdx_explicit=0,
+              const int w_recursion_depth=0)
+        : Model(nx_rdata, nxtrue_rdata, nx_solver, nxtrue_solver,
+                nx_solver_reinit, ny, nytrue, nz, nztrue, ne, nJ, nw, ndwdx,
+                ndwdp, ndwdw, ndxdotdw, std::move(ndJydy), nnz, ubw, lbw,
+                o2mode, p, k, plist, idlist, z2event, pythonGenerated,
+                ndxdotdp_explicit, ndxdotdx_explicit, w_recursion_depth) {}
 
     void fJ(realtype t, realtype cj, const AmiVector &x, const AmiVector &dx,
             const AmiVector &xdot, SUNMatrix J) override;
@@ -193,7 +198,7 @@ class Model_ODE : public Model {
     /**
      * @brief Implementation of froot at the N_Vector level
      * This function provides an interface to the model specific routines for
-     * the solver implementation aswell as the AmiVector level implementation
+     * the solver implementation as well as the AmiVector level implementation
      * @param t timepoint
      * @param x Vector with the states
      * @param root array with root function values
@@ -206,7 +211,7 @@ class Model_ODE : public Model {
     /**
      * @brief Implementation of fxdot at the N_Vector level, this function
      * provides an interface to the model specific routines for the solver
-     * implementation aswell as the AmiVector level implementation
+     * implementation as well as the AmiVector level implementation
      * @param t timepoint
      * @param x Vector with the states
      * @param xdot Vector with the right hand side
@@ -272,21 +277,6 @@ class Model_ODE : public Model {
                             const AmiVector &xB, const AmiVector &dxB,
                             const AmiVector &xBdot) override;
 
-    /**
-     * @brief Sensitivity of dx/dt wrt model parameters w
-     * @param t timepoint
-     * @param x Vector with the states
-     */
-    void fdxdotdw(realtype t, const N_Vector x);
-
-    /** Explicit sensitivity of dx/dt wrt model parameters p
-     * @param t timepoint
-     * @param x Vector with the states
-     */
-    void fdxdotdp(realtype t, const N_Vector x);
-
-    void fdxdotdp(realtype t, const AmiVector &x, const AmiVector &dx) override;
-
     void fsxdot(realtype t, const AmiVector &x, const AmiVector &dx, int ip,
                 const AmiVector &sx, const AmiVector &sdx,
                 AmiVector &sxdot) override;
@@ -304,46 +294,15 @@ class Model_ODE : public Model {
     std::unique_ptr<Solver> getSolver() override;
 
   protected:
-    /**
-     * @brief Model specific implementation for fJ
-     * @param J Matrix to which the Jacobian will be written
-     * @param t timepoint
-     * @param x Vector with the states
-     * @param p parameter vector
-     * @param k constants vector
-     * @param h heavyside vector
-     * @param w vector with helper variables
-     * @param dwdx derivative of w wrt x
-     **/
-    virtual void fJ(realtype *J, realtype t, const realtype *x,
-                    const realtype *p, const realtype *k, const realtype *h,
-                    const realtype *w, const realtype *dwdx) = 0;
 
     /**
-     * @brief Model specific implementation for fJB
-     * @param JB Matrix to which the Jacobian will be written
-     * @param t timepoint
-     * @param x Vector with the states
-     * @param p parameter vector
-     * @param k constants vector
-     * @param h heavyside vector
-     * @param xB Vector with the adjoint states
-     * @param w vector with helper variables
-     * @param dwdx derivative of w wrt x
-     **/
-    virtual void fJB(realtype *JB, realtype t, const realtype *x,
-                     const realtype *p, const realtype *k, const realtype *h,
-                     const realtype *xB, const realtype *w,
-                     const realtype *dwdx);
-
-    /**
-     * @brief Model specific implementation for fJSparse
+     * @brief Model specific implementation for fJSparse (Matlab)
      * @param JSparse Matrix to which the Jacobian will be written
      * @param t timepoint
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param w vector with helper variables
      * @param dwdx derivative of w wrt x
      **/
@@ -353,13 +312,13 @@ class Model_ODE : public Model {
                           const realtype *w, const realtype *dwdx);
 
     /**
-     * @brief Model specific implementation for fJSparse, data only
+     * @brief Model specific implementation for fJSparse, data only (Py)
      * @param JSparse Matrix to which the Jacobian will be written
      * @param t timepoint
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param w vector with helper variables
      * @param dwdx derivative of w wrt x
      **/
@@ -370,77 +329,15 @@ class Model_ODE : public Model {
 
     /**
      * @brief Model specific implementation for fJSparse, column pointers
-     * @param indexptrs column pointers
+     * @param JSparse sparse matrix to which colptrs will be written
      **/
-    virtual void fJSparse_colptrs(sunindextype *indexptrs);
+    virtual void fJSparse_colptrs(SUNMatrixWrapper &JSparse);
 
     /**
      * @brief Model specific implementation for fJSparse, row values
-     * @param indexvals row values
+     * @param JSparse sparse matrix to which rowvals will be written
      **/
-    virtual void fJSparse_rowvals(sunindextype *indexvals);
-
-    /**
-     * @brief Model specific implementation for fJSparseB
-     * @param JSparseB Matrix to which the Jacobian will be written
-     * @param t timepoint
-     * @param x Vector with the states
-     * @param p parameter vector
-     * @param k constants vector
-     * @param h heavyside vector
-     * @param xB Vector with the adjoint states
-     * @param w vector with helper variables
-     * @param dwdx derivative of w wrt x
-     **/
-    virtual void fJSparseB(SUNMatrixContent_Sparse JSparseB, realtype t,
-                           const realtype *x, const realtype *p,
-                           const realtype *k, const realtype *h,
-                           const realtype *xB, const realtype *w,
-                           const realtype *dwdx);
-
-    /**
-     * @brief Model specific implementation for fJSparseB
-     * @param JSparseB data array
-     * @param t timepoint
-     * @param x Vector with the states
-     * @param p parameter vector
-     * @param k constants vector
-     * @param h heavyside vector
-     * @param xB Vector with the adjoint states
-     * @param w vector with helper variables
-     * @param dwdx derivative of w wrt x
-     **/
-    virtual void fJSparseB(realtype *JSparseB, realtype t, const realtype *x,
-                           const realtype *p, const realtype *k,
-                           const realtype *h, const realtype *xB,
-                           const realtype *w, const realtype *dwdx);
-
-    /**
-     * @brief Model specific implementation for fJSparse, column pointers
-     * @param indexptrs column pointers
-     **/
-    virtual void fJSparseB_colptrs(sunindextype *indexptrs);
-
-    /**
-     * @brief Model specific implementation for fJSparse, row values
-     * @param indexvals row values
-     **/
-    virtual void fJSparseB_rowvals(sunindextype *indexvals);
-
-    /**
-     * @brief Model specific implementation for fJDiag
-     * @param JDiag Matrix to which the Jacobian will be written
-     * @param t timepoint
-     * @param x Vector with the states
-     * @param p parameter vector
-     * @param k constants vector
-     * @param h heavyside vector
-     * @param w vector with helper variables
-     * @param dwdx derivative of w wrt x
-     **/
-    virtual void fJDiag(realtype *JDiag, realtype t, const realtype *x,
-                        const realtype *p, const realtype *k, const realtype *h,
-                        const realtype *w, const realtype *dwdx);
+    virtual void fJSparse_rowvals(SUNMatrixWrapper &JSparse);
 
     /**
      * @brief Model specific implementation for froot
@@ -449,7 +346,7 @@ class Model_ODE : public Model {
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      **/
     virtual void froot(realtype *root, realtype t, const realtype *x,
                        const realtype *p, const realtype *k, const realtype *h);
@@ -461,7 +358,7 @@ class Model_ODE : public Model {
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param w vector with helper variables
      **/
     virtual void fxdot(realtype *xdot, realtype t, const realtype *x,
@@ -475,7 +372,7 @@ class Model_ODE : public Model {
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param ip parameter index
      * @param w vector with helper variables
      * @param dwdp derivative of w wrt p
@@ -492,7 +389,7 @@ class Model_ODE : public Model {
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param w vector with helper variables
      */
     virtual void fdxdotdp_explicit(realtype *dxdotdp_explicit, realtype t,
@@ -502,27 +399,42 @@ class Model_ODE : public Model {
 
     /**
      * @brief Model specific implementation of fdxdotdp_explicit, colptrs part
-     * @param indexptrs column pointers
+     * @param dxdotdp sparse matrix to which colptrs will be written
      */
-    virtual void fdxdotdp_explicit_colptrs(sunindextype *indexptrs);
+    virtual void fdxdotdp_explicit_colptrs(SUNMatrixWrapper &dxdotdp);
 
     /**
      * @brief Model specific implementation of fdxdotdp_explicit, rowvals part
-     * @param indexvals row values
+     * @param dxdotdp sparse matrix to which rowvals will be written
      */
-    virtual void fdxdotdp_explicit_rowvals(sunindextype *indexvals);
+    virtual void fdxdotdp_explicit_rowvals(SUNMatrixWrapper &dxdotdp);
+    
+    /**
+     * @brief Model specific implementation of fdxdotdx_explicit, no w chainrule (Py)
+     * @param dxdotdx_explicit partial derivative xdot wrt x
+     * @param t timepoint
+     * @param x Vector with the states
+     * @param p parameter vector
+     * @param k constants vector
+     * @param h heavyside vector
+     * @param w vector with helper variables
+     */
+    virtual void fdxdotdx_explicit(realtype *dxdotdx_explicit, realtype t,
+                                   const realtype *x, const realtype *p,
+                                   const realtype *k, const realtype *h,
+                                   const realtype *w);
 
     /**
-     * @brief Model specific implementation of fdxdotdp_implicit, colptrs part
-     * @param indexptrs column pointers
+     * @brief Model specific implementation of fdxdotdx_explicit, colptrs part
+     * @param dxdotdx sparse matrix to which colptrs will be written
      */
-    virtual void fdxdotdp_implicit_colptrs(sunindextype *indexptrs);
+    virtual void fdxdotdx_explicit_colptrs(SUNMatrixWrapper &dxdotdx);
 
     /**
-     * @brief Model specific implementation of fdxdotdp_implicit, rowvals part
-     * @param indexvals row values
+     * @brief Model specific implementation of fdxdotdx_explicit, rowvals part
+     * @param dxdotdx sparse matrix to which rowvals will be written
      */
-    virtual void fdxdotdp_implicit_rowvals(sunindextype *indexvals);
+    virtual void fdxdotdx_explicit_rowvals(SUNMatrixWrapper &dxdotdx);
 
     /**
      * @brief Model specific implementation of fdxdotdw, data part
@@ -531,7 +443,7 @@ class Model_ODE : public Model {
      * @param x Vector with the states
      * @param p parameter vector
      * @param k constants vector
-     * @param h heavyside vector
+     * @param h Heaviside vector
      * @param w vector with helper variables
      */
     virtual void fdxdotdw(realtype *dxdotdw, realtype t, const realtype *x,
@@ -540,15 +452,30 @@ class Model_ODE : public Model {
 
     /**
      * @brief Model specific implementation of fdxdotdw, colptrs part
-     * @param indexptrs column pointers
+     * @param dxdotdw sparse matrix to which colptrs will be written
      */
-    virtual void fdxdotdw_colptrs(sunindextype *indexptrs);
+    virtual void fdxdotdw_colptrs(SUNMatrixWrapper &dxdotdw);
 
     /**
      * @brief Model specific implementation of fdxdotdw, rowvals part
-     * @param indexvals row values
+     * @param dxdotdw sparse matrix to which rowvals will be written
      */
-    virtual void fdxdotdw_rowvals(sunindextype *indexvals);
+    virtual void fdxdotdw_rowvals(SUNMatrixWrapper &dxdotdw);
+    
+    /**
+     * @brief Sensitivity of dx/dt wrt model parameters w
+     * @param t timepoint
+     * @param x Vector with the states
+     */
+    void fdxdotdw(realtype t, const N_Vector x);
+
+    /** Explicit sensitivity of dx/dt wrt model parameters p
+     * @param t timepoint
+     * @param x Vector with the states
+     */
+    void fdxdotdp(realtype t, const N_Vector x);
+
+    void fdxdotdp(realtype t, const AmiVector &x, const AmiVector &dx) override;
 };
 } // namespace amici
 
