@@ -107,14 +107,12 @@ AmiciApplication::runAmiciSimulation(Solver& solver,
     std::unique_ptr<ReturnData> rdata = std::make_unique<ReturnData>(solver,
                                                                      model);
 
-    if (model.nx_solver <= 0) {
-        return rdata;
-    }
-
     std::unique_ptr<SteadystateProblem> preeq {};
     std::unique_ptr<ForwardProblem> fwd {};
     std::unique_ptr<BackwardProblem> bwd {};
     std::unique_ptr<SteadystateProblem> posteq {};
+    // tracks whether backwards integration finished without exceptions
+    bool bwd_success = true;
 
     try {
         if (solver.getPreequilibration() ||
@@ -148,10 +146,12 @@ AmiciApplication::runAmiciSimulation(Solver& solver,
                                                        bwd.get());
             }
 
+            bwd_success = false;
 
             bwd = std::make_unique<BackwardProblem>(*fwd, posteq.get());
             bwd->workBackwardProblem();
 
+            bwd_success = true;
 
             if (preeq) {
                 ConditionContext cc2(&model, edata,
@@ -191,8 +191,10 @@ AmiciApplication::runAmiciSimulation(Solver& solver,
                  ex.getBacktrace());
     }
 
-    rdata->processSimulationObjects(preeq.get(), fwd.get(), bwd.get(),
-                                    posteq.get(), model, solver, edata);
+    rdata->processSimulationObjects(
+        preeq.get(), fwd.get(),
+        bwd_success ? bwd.get() : nullptr,
+        posteq.get(), model, solver, edata);
     return rdata;
 }
 
