@@ -367,8 +367,13 @@ void writeReturnDataDiagnosis(const ReturnData &rdata,
                     file, hdf5Location + "/numnonlinsolvconvfailsB",
                     rdata.numnonlinsolvconvfailsB);
 
-    H5LTset_attribute_int(file.getId(), (hdf5Location + "").c_str(),
-                          "preeq_status", &rdata.preeq_status, 1);
+    if (!rdata.preeq_status.empty()) {
+        std::vector<int> preeq_status_int (rdata.preeq_status.size());
+        for (int i = 0; (unsigned)i < rdata.preeq_status.size(); i++)
+            preeq_status_int[i] = static_cast<int>(rdata.preeq_status[i]);
+        createAndWriteInt1DDataset(file, hdf5Location + "/preeq_status",
+                                   preeq_status_int);
+    }
 
     if (!rdata.preeq_numsteps.empty())
         createAndWriteInt1DDataset(file, hdf5Location + "/preeq_numsteps",
@@ -379,17 +384,28 @@ void writeReturnDataDiagnosis(const ReturnData &rdata,
                                    rdata.preeq_numlinsteps,
                                    rdata.newton_maxsteps, 2);
 
+    H5LTset_attribute_int(file.getId(), hdf5Location.c_str(),
+                          "preeq_numstepsB", &rdata.preeq_numstepsB, 1);
+
     H5LTset_attribute_double(file.getId(), hdf5Location.c_str(),
                              "preeq_cpu_time", &rdata.preeq_cpu_time, 1);
 
+    H5LTset_attribute_double(file.getId(), hdf5Location.c_str(),
+                             "preeq_cpu_timeB", &rdata.preeq_cpu_timeB, 1);
+
     H5LTset_attribute_double(file.getId(), hdf5Location.c_str(), "preeq_t",
                              &rdata.preeq_t, 1);
 
     H5LTset_attribute_double(file.getId(), hdf5Location.c_str(), "preeq_wrms",
                              &rdata.preeq_wrms, 1);
 
-    H5LTset_attribute_int(file.getId(), (hdf5Location + "").c_str(),
-                          "posteq_status", &rdata.posteq_status, 1);
+    if (!rdata.posteq_status.empty()) {
+        std::vector<int> posteq_status_int (rdata.posteq_status.size());
+        for (int i = 0; (unsigned)i < rdata.posteq_status.size(); i++)
+            posteq_status_int[i] = static_cast<int>(rdata.posteq_status[i]);
+        createAndWriteInt1DDataset(file, hdf5Location + "/posteq_status",
+                                   posteq_status_int);
+    }
 
     if (!rdata.posteq_numsteps.empty())
         createAndWriteInt1DDataset(file, hdf5Location + "/posteq_numsteps",
@@ -400,9 +416,15 @@ void writeReturnDataDiagnosis(const ReturnData &rdata,
                                    rdata.posteq_numlinsteps,
                                    rdata.newton_maxsteps, 2);
 
+    H5LTset_attribute_int(file.getId(), hdf5Location.c_str(),
+                          "posteq_numstepsB", &rdata.posteq_numstepsB, 1);
+
     H5LTset_attribute_double(file.getId(), hdf5Location.c_str(),
                              "posteq_cpu_time", &rdata.posteq_cpu_time, 1);
 
+    H5LTset_attribute_double(file.getId(), hdf5Location.c_str(),
+                             "posteq_cpu_timeB", &rdata.posteq_cpu_timeB, 1);
+
     H5LTset_attribute_double(file.getId(), hdf5Location.c_str(), "posteq_t",
                              &rdata.posteq_t, 1);
 
@@ -637,6 +659,10 @@ void writeSolverSettingsToHDF5(Solver const& solver,
     H5LTset_attribute_int(file.getId(), hdf5Location.c_str(),
                           "sensi_meth", &ibuffer, 1);
 
+    ibuffer = static_cast<int>(solver.getSensitivityMethodPreequilibration());
+    H5LTset_attribute_int(file.getId(), hdf5Location.c_str(),
+                          "sensi_meth_preeq", &ibuffer, 1);
+
     ibuffer = static_cast<int>(solver.getSensitivityOrder());
     H5LTset_attribute_int(file.getId(), hdf5Location.c_str(),
                           "sensi", &ibuffer, 1);
@@ -785,6 +811,12 @@ void readSolverSettingsFromHDF5(H5::H5File const& file, Solver &solver,
                         getIntScalarAttribute(file, datasetPath, "sensi_meth")));
     }
 
+    if(attributeExists(file, datasetPath, "sensi_meth_preeq")) {
+        solver.setSensitivityMethodPreequilibration(
+            static_cast<SensitivityMethod>(
+                getIntScalarAttribute(file, datasetPath, "sensi_meth_preeq")));
+    }
+
     if(attributeExists(file, datasetPath, "sensi")) {
         solver.setSensitivityOrder(
                     static_cast<SensitivityOrder>(
